"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_instance_groups(InstanceGroups=None, JobFlowId=None):
    """
    :param InstanceGroups: [REQUIRED]
            Instance Groups to add.
            (dict) --Configuration defining a new instance group.
            Name (string) --Friendly name given to the instance group.
            Market (string) --Market type of the Amazon EC2 instances used to create a cluster node.
            InstanceRole (string) -- [REQUIRED]The role of the instance group in the cluster.
            BidPrice (string) --Bid price for each Amazon EC2 instance in the instance group when launching nodes as Spot Instances, expressed in USD.
            InstanceType (string) -- [REQUIRED]The Amazon EC2 instance type for all instances in the instance group.
            InstanceCount (integer) -- [REQUIRED]Target number of instances for the instance group.
            Configurations (list) --
            Note
            Amazon EMR releases 4.x or later.
            The list of configurations supplied for an EMR cluster instance group. You can specify a separate configuration for each instance group (master, core, and task).
            (dict) --
            Note
            Amazon EMR releases 4.x or later.
            Specifies a hardware and software configuration of the EMR cluster. This includes configurations for applications and software bundled with Amazon EMR. The Configuration object is a JSON object which is defined by a classification and a set of properties. Configurations can be nested, so a configuration may have its own Configuration objects listed.
            Classification (string) --The classification of a configuration. For more information see, Amazon EMR Configurations .
            Configurations (list) --A list of configurations you apply to this configuration object.
            Properties (dict) --A set of properties supplied to the Configuration object.
            (string) --
            (string) --
            
            
            EbsConfiguration (dict) --EBS configurations that will be attached to each Amazon EC2 instance in the instance group.
            EbsBlockDeviceConfigs (list) --
            (dict) --Configuration of requested EBS block device associated with the instance group with count of volumes that will be associated to every instance.
            VolumeSpecification (dict) -- [REQUIRED]EBS volume specifications such as volume type, IOPS, and size(GiB) that will be requested for the EBS volume attached to an EC2 instance in the cluster.
            VolumeType (string) -- [REQUIRED]The volume type. Volume types supported are gp2, io1, standard.
            Iops (integer) --The number of I/O operations per second (IOPS) that the volume supports.
            SizeInGB (integer) -- [REQUIRED]The volume size, in gibibytes (GiB). This can be a number from 1 - 1024. If the volume type is EBS-optimized, the minimum value is 10.
            VolumesPerInstance (integer) --Number of EBS volumes with specific volume configuration, that will be associated with every instance in the instance group
            
            EbsOptimized (boolean) --
            
            
    :type InstanceGroups: list
    :param JobFlowId: [REQUIRED]
            Job flow in which to add the instance groups.
            
    :type JobFlowId: string
    """
    pass

def add_job_flow_steps(JobFlowId=None, Steps=None):
    """
    :param JobFlowId: [REQUIRED]
            A string that uniquely identifies the job flow. This identifier is returned by RunJobFlow and can also be obtained from ListClusters .
            
    :type JobFlowId: string
    :param Steps: [REQUIRED]
            A list of StepConfig to be executed by the job flow.
            (dict) --Specification of a job flow step.
            Name (string) -- [REQUIRED]The name of the job flow step.
            ActionOnFailure (string) --The action to take if the job flow step fails.
            HadoopJarStep (dict) -- [REQUIRED]The JAR file used for the job flow step.
            Properties (list) --A list of Java properties that are set when the step runs. You can use these properties to pass key value pairs to your main function.
            (dict) --A key value pair.
            Key (string) --The unique identifier of a key value pair.
            Value (string) --The value part of the identified key.
            
            Jar (string) -- [REQUIRED]A path to a JAR file run during the step.
            MainClass (string) --The name of the main class in the specified Java file. If not specified, the JAR file should specify a Main-Class in its manifest file.
            Args (list) --A list of command line arguments passed to the JAR file's main function when executed.
            (string) --
            
            
    :type Steps: list
    """
    pass

def add_tags(ResourceId=None, Tags=None):
    """
    :param ResourceId: [REQUIRED]
            The Amazon EMR resource identifier to which tags will be added. This value must be a cluster identifier.
            
    :type ResourceId: string
    :param Tags: [REQUIRED]
            A list of tags to associate with a cluster and propagate to Amazon EC2 instances. Tags are user-defined key/value pairs that consist of a required key string with a maximum of 128 characters, and an optional value string with a maximum of 256 characters.
            (dict) --A key/value pair containing user-defined metadata that you can associate with an Amazon EMR resource. Tags make it easier to associate clusters in various ways, such as grouping clusters to track your Amazon EMR resource allocation costs. For more information, see Tagging Amazon EMR Resources .
            Key (string) --A user-defined key, which is the minimum required information for a valid tag. For more information, see Tagging Amazon EMR Resources .
            Value (string) --A user-defined value, which is optional in a tag. For more information, see Tagging Amazon EMR Resources .
            
            
    :type Tags: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_security_configuration(Name=None, SecurityConfiguration=None):
    """
    :param Name: [REQUIRED]
            The name of the security configuration.
            
    :type Name: string
    :param SecurityConfiguration: [REQUIRED]
            The security configuration details in JSON format.
            
    :type SecurityConfiguration: string
    """
    pass

def delete_security_configuration(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the security configuration.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type Name: string
    """
    pass

def describe_cluster(ClusterId=None):
    """
    :param ClusterId: [REQUIRED]
            The identifier of the cluster to describe.
            Return typedict
            ReturnsResponse Syntax{
              'Cluster': {
                'Id': 'string',
                'Name': 'string',
                'Status': {
                  'State': 'STARTING'|'BOOTSTRAPPING'|'RUNNING'|'WAITING'|'TERMINATING'|'TERMINATED'|'TERMINATED_WITH_ERRORS',
                  'StateChangeReason': {
                    'Code': 'INTERNAL_ERROR'|'VALIDATION_ERROR'|'INSTANCE_FAILURE'|'BOOTSTRAP_FAILURE'|'USER_REQUEST'|'STEP_FAILURE'|'ALL_STEPS_COMPLETED',
                    'Message': 'string'
                  },
                  'Timeline': {
                    'CreationDateTime': datetime(2015, 1, 1),
                    'ReadyDateTime': datetime(2015, 1, 1),
                    'EndDateTime': datetime(2015, 1, 1)
                  }
                },
                'Ec2InstanceAttributes': {
                  'Ec2KeyName': 'string',
                  'Ec2SubnetId': 'string',
                  'Ec2AvailabilityZone': 'string',
                  'IamInstanceProfile': 'string',
                  'EmrManagedMasterSecurityGroup': 'string',
                  'EmrManagedSlaveSecurityGroup': 'string',
                  'ServiceAccessSecurityGroup': 'string',
                  'AdditionalMasterSecurityGroups': [
                    'string',
                  ],
                  'AdditionalSlaveSecurityGroups': [
                    'string',
                  ]
                },
                'LogUri': 'string',
                'RequestedAmiVersion': 'string',
                'RunningAmiVersion': 'string',
                'ReleaseLabel': 'string',
                'AutoTerminate': True|False,
                'TerminationProtected': True|False,
                'VisibleToAllUsers': True|False,
                'Applications': [
                  {
                    'Name': 'string',
                    'Version': 'string',
                    'Args': [
                      'string',
                    ],
                    'AdditionalInfo': {
                      'string': 'string'
                    }
                  },
                ],
                'Tags': [
                  {
                    'Key': 'string',
                    'Value': 'string'
                  },
                ],
                'ServiceRole': 'string',
                'NormalizedInstanceHours': 123,
                'MasterPublicDnsName': 'string',
                'Configurations': [
                  {
                    'Classification': 'string',
                    'Configurations': {'... recursive ...'},
                    'Properties': {
                      'string': 'string'
                    }
                  },
                ],
                'SecurityConfiguration': 'string'
              }
            }
            Response Structure
            (dict) --This output contains the description of the cluster.
            Cluster (dict) --This output contains the details for the requested cluster.
            Id (string) --The unique identifier for the cluster.
            Name (string) --The name of the cluster.
            Status (dict) --The current status details about the cluster.
            State (string) --The current state of the cluster.
            StateChangeReason (dict) --The reason for the cluster status change.
            Code (string) --The programmatic code for the state change reason.
            Message (string) --The descriptive message for the state change reason.
            Timeline (dict) --A timeline that represents the status of a cluster over the lifetime of the cluster.
            CreationDateTime (datetime) --The creation date and time of the cluster.
            ReadyDateTime (datetime) --The date and time when the cluster was ready to execute steps.
            EndDateTime (datetime) --The date and time when the cluster was terminated.
            
            Ec2InstanceAttributes (dict) --Provides information about the EC2 instances in a cluster grouped by category. For example, key name, subnet ID, IAM instance profile, and so on.
            Ec2KeyName (string) --The name of the Amazon EC2 key pair to use when connecting with SSH into the master node as a user named 'hadoop'.
            Ec2SubnetId (string) --To launch the job flow in Amazon VPC, set this parameter to the identifier of the Amazon VPC subnet where you want the job flow to launch. If you do not specify this value, the job flow is launched in the normal AWS cloud, outside of a VPC.
            Amazon VPC currently does not support cluster compute quadruple extra large (cc1.4xlarge) instances. Thus, you cannot specify the cc1.4xlarge instance type for nodes of a job flow launched in a VPC.
            Ec2AvailabilityZone (string) --The Availability Zone in which the cluster will run.
            IamInstanceProfile (string) --The IAM role that was specified when the job flow was launched. The EC2 instances of the job flow assume this role.
            EmrManagedMasterSecurityGroup (string) --The identifier of the Amazon EC2 security group for the master node.
            EmrManagedSlaveSecurityGroup (string) --The identifier of the Amazon EC2 security group for the slave nodes.
            ServiceAccessSecurityGroup (string) --The identifier of the Amazon EC2 security group for the Amazon EMR service to access clusters in VPC private subnets.
            AdditionalMasterSecurityGroups (list) --A list of additional Amazon EC2 security group IDs for the master node.
            (string) --
            AdditionalSlaveSecurityGroups (list) --A list of additional Amazon EC2 security group IDs for the slave nodes.
            (string) --
            
            LogUri (string) --The path to the Amazon S3 location where logs for this cluster are stored.
            RequestedAmiVersion (string) --The AMI version requested for this cluster.
            RunningAmiVersion (string) --The AMI version running on this cluster.
            ReleaseLabel (string) --The release label for the Amazon EMR release. For Amazon EMR 3.x and 2.x AMIs, use amiVersion instead instead of ReleaseLabel.
            AutoTerminate (boolean) --Specifies whether the cluster should terminate after completing all steps.
            TerminationProtected (boolean) --Indicates whether Amazon EMR will lock the cluster to prevent the EC2 instances from being terminated by an API call or user intervention, or in the event of a cluster error.
            VisibleToAllUsers (boolean) --Indicates whether the job flow is visible to all IAM users of the AWS account associated with the job flow. If this value is set to true , all IAM users of that AWS account can view and manage the job flow if they have the proper policy permissions set. If this value is false , only the IAM user that created the cluster can view and manage it. This value can be changed using the SetVisibleToAllUsers action.
            Applications (list) --The applications installed on this cluster.
            (dict) --An application is any Amazon or third-party software that you can add to the cluster. This structure contains a list of strings that indicates the software to use with the cluster and accepts a user argument list. Amazon EMR accepts and forwards the argument list to the corresponding installation script as bootstrap action argument. For more information, see Launch a Job Flow on the MapR Distribution for Hadoop . Currently supported values are:
            'mapr-m3' - launch the job flow using MapR M3 Edition.
            'mapr-m5' - launch the job flow using MapR M5 Edition.
            'mapr' with the user arguments specifying '--edition,m3' or '--edition,m5' - launch the job flow using MapR M3 or M5 Edition, respectively.
            Note
            In Amazon EMR releases 4.0 and greater, the only accepted parameter is the application name. To pass arguments to applications, you supply a configuration for each application.
            Name (string) --The name of the application.
            Version (string) --The version of the application.
            Args (list) --Arguments for Amazon EMR to pass to the application.
            (string) --
            AdditionalInfo (dict) --This option is for advanced users only. This is meta information about third-party applications that third-party vendors use for testing purposes.
            (string) --
            (string) --
            
            
            Tags (list) --A list of tags associated with a cluster.
            (dict) --A key/value pair containing user-defined metadata that you can associate with an Amazon EMR resource. Tags make it easier to associate clusters in various ways, such as grouping clusters to track your Amazon EMR resource allocation costs. For more information, see Tagging Amazon EMR Resources .
            Key (string) --A user-defined key, which is the minimum required information for a valid tag. For more information, see Tagging Amazon EMR Resources .
            Value (string) --A user-defined value, which is optional in a tag. For more information, see Tagging Amazon EMR Resources .
            
            ServiceRole (string) --The IAM role that will be assumed by the Amazon EMR service to access AWS resources on your behalf.
            NormalizedInstanceHours (integer) --An approximation of the cost of the job flow, represented in m1.small/hours. This value is incremented one time for every hour an m1.small instance runs. Larger instances are weighted more, so an EC2 instance that is roughly four times more expensive would result in the normalized instance hours being incremented by four. This result is only an approximation and does not reflect the actual billing rate.
            MasterPublicDnsName (string) --The public DNS name of the master EC2 instance.
            Configurations (list) --
            Note
            Amazon EMR releases 4.x or later.
            The list of Configurations supplied to the EMR cluster.
            (dict) --
            Note
            Amazon EMR releases 4.x or later.
            Specifies a hardware and software configuration of the EMR cluster. This includes configurations for applications and software bundled with Amazon EMR. The Configuration object is a JSON object which is defined by a classification and a set of properties. Configurations can be nested, so a configuration may have its own Configuration objects listed.
            Classification (string) --The classification of a configuration. For more information see, Amazon EMR Configurations .
            Configurations (list) --A list of configurations you apply to this configuration object.
            Properties (dict) --A set of properties supplied to the Configuration object.
            (string) --
            (string) --
            
            
            SecurityConfiguration (string) --The name of the security configuration applied to the cluster.
            
            
            
    :type ClusterId: string
    """
    pass

def describe_job_flows(CreatedAfter=None, CreatedBefore=None, JobFlowIds=None, JobFlowStates=None):
    """
    :param CreatedAfter: Return only job flows created after this date and time.
    :type CreatedAfter: datetime
    :param CreatedBefore: Return only job flows created before this date and time.
    :type CreatedBefore: datetime
    :param JobFlowIds: Return only job flows whose job flow ID is contained in this list.
            (string) --
            
    :type JobFlowIds: list
    :param JobFlowStates: Return only job flows whose state is contained in this list.
            (string) --The type of instance.
            
    :type JobFlowStates: list
    """
    pass

def describe_security_configuration(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the security configuration.
            Return typedict
            ReturnsResponse Syntax{
              'Name': 'string',
              'SecurityConfiguration': 'string',
              'CreationDateTime': datetime(2015, 1, 1)
            }
            Response Structure
            (dict) --
            Name (string) --The name of the security configuration.
            SecurityConfiguration (string) --The security configuration details in JSON format.
            CreationDateTime (datetime) --The date and time the security configuration was created
            
            
    :type Name: string
    """
    pass

def describe_step(ClusterId=None, StepId=None):
    """
    :param ClusterId: [REQUIRED]
            The identifier of the cluster with steps to describe.
            
    :type ClusterId: string
    :param StepId: [REQUIRED]
            The identifier of the step to describe.
            
    :type StepId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_bootstrap_actions(ClusterId=None, Marker=None):
    """
    :param ClusterId: [REQUIRED]
            The cluster identifier for the bootstrap actions to list .
            
    :type ClusterId: string
    :param Marker: The pagination token that indicates the next set of results to retrieve.
    :type Marker: string
    """
    pass

def list_clusters(CreatedAfter=None, CreatedBefore=None, ClusterStates=None, Marker=None):
    """
    :param CreatedAfter: The creation date and time beginning value filter for listing clusters .
    :type CreatedAfter: datetime
    :param CreatedBefore: The creation date and time end value filter for listing clusters .
    :type CreatedBefore: datetime
    :param ClusterStates: The cluster state filters to apply when listing clusters.
            (string) --
            
    :type ClusterStates: list
    :param Marker: The pagination token that indicates the next set of results to retrieve.
    :type Marker: string
    """
    pass

def list_instance_groups(ClusterId=None, Marker=None):
    """
    :param ClusterId: [REQUIRED]
            The identifier of the cluster for which to list the instance groups.
            
    :type ClusterId: string
    :param Marker: The pagination token that indicates the next set of results to retrieve.
    :type Marker: string
    """
    pass

def list_instances(ClusterId=None, InstanceGroupId=None, InstanceGroupTypes=None, InstanceStates=None, Marker=None):
    """
    :param ClusterId: [REQUIRED]
            The identifier of the cluster for which to list the instances.
            
    :type ClusterId: string
    :param InstanceGroupId: The identifier of the instance group for which to list the instances.
    :type InstanceGroupId: string
    :param InstanceGroupTypes: The type of instance group for which to list the instances.
            (string) --
            
    :type InstanceGroupTypes: list
    :param InstanceStates: A list of instance states that will filter the instances returned with this request.
            (string) --
            
    :type InstanceStates: list
    :param Marker: The pagination token that indicates the next set of results to retrieve.
    :type Marker: string
    """
    pass

def list_security_configurations(Marker=None):
    """
    :param Marker: The pagination token that indicates the set of results to retrieve.
            Return typedict
            ReturnsResponse Syntax{
              'SecurityConfigurations': [
                {
                  'Name': 'string',
                  'CreationDateTime': datetime(2015, 1, 1)
                },
              ],
              'Marker': 'string'
            }
            Response Structure
            (dict) --
            SecurityConfigurations (list) --The creation date and time, and name, of each security configuration.
            (dict) --The creation date and time, and name, of a security configuration.
            Name (string) --The name of the security configuration.
            CreationDateTime (datetime) --The date and time the security configuration was created.
            
            Marker (string) --A pagination token that indicates the next set of results to retrieve. Include the marker in the next ListSecurityConfiguration call to retrieve the next page of results, if required.
            
            
    :type Marker: string
    """
    pass

def list_steps(ClusterId=None, StepStates=None, StepIds=None, Marker=None):
    """
    :param ClusterId: [REQUIRED]
            The identifier of the cluster for which to list the steps.
            
    :type ClusterId: string
    :param StepStates: The filter to limit the step list based on certain states.
            (string) --
            
    :type StepStates: list
    :param StepIds: The filter to limit the step list based on the identifier of the steps.
            (string) --
            
    :type StepIds: list
    :param Marker: The pagination token that indicates the next set of results to retrieve.
    :type Marker: string
    """
    pass

def modify_instance_groups(InstanceGroups=None):
    """
    :param InstanceGroups: Instance groups to change.
            (dict) --Modify an instance group size.
            InstanceGroupId (string) -- [REQUIRED]Unique ID of the instance group to expand or shrink.
            InstanceCount (integer) --Target size for the instance group.
            EC2InstanceIdsToTerminate (list) --The EC2 InstanceIds to terminate. Once you terminate the instances, the instance group will not return to its original requested size.
            (string) --
            ShrinkPolicy (dict) --Policy for customizing shrink operations.
            DecommissionTimeout (integer) --The desired timeout for decommissioning an instance. Overrides the default YARN decommissioning timeout.
            InstanceResizePolicy (dict) --Custom policy for requesting termination protection or termination of specific instances when shrinking an instance group.
            InstancesToTerminate (list) --Specific list of instances to be terminated when shrinking an instance group.
            (string) --
            InstancesToProtect (list) --Specific list of instances to be protected when shrinking an instance group.
            (string) --
            InstanceTerminationTimeout (integer) --Decommissioning timeout override for the specific list of instances to be terminated.
            
            
            ReturnsNone
            
    :type InstanceGroups: list
    """
    pass

def remove_tags(ResourceId=None, TagKeys=None):
    """
    :param ResourceId: [REQUIRED]
            The Amazon EMR resource identifier from which tags will be removed. This value must be a cluster identifier.
            
    :type ResourceId: string
    :param TagKeys: [REQUIRED]
            A list of tag keys to remove from a resource.
            (string) --
            
    :type TagKeys: list
    """
    pass

def run_job_flow(Name=None, LogUri=None, AdditionalInfo=None, AmiVersion=None, ReleaseLabel=None, Instances=None, Steps=None, BootstrapActions=None, SupportedProducts=None, NewSupportedProducts=None, Applications=None, Configurations=None, VisibleToAllUsers=None, JobFlowRole=None, ServiceRole=None, Tags=None, SecurityConfiguration=None):
    """
    :param Name: [REQUIRED]
            The name of the job flow.
            
    :type Name: string
    :param LogUri: The location in Amazon S3 to write the log files of the job flow. If a value is not provided, logs are not created.
    :type LogUri: string
    :param AdditionalInfo: A JSON string for selecting additional features.
    :type AdditionalInfo: string
    :param AmiVersion: 
            Note
            For Amazon EMR releases 3.x and 2.x. For Amazon EMR releases 4.x and greater, use ReleaseLabel.
            The version of the Amazon Machine Image (AMI) to use when launching Amazon EC2 instances in the job flow. The following values are valid:
            The version number of the AMI to use, for example, '2.0.'
            If the AMI supports multiple versions of Hadoop (for example, AMI 1.0 supports both Hadoop 0.18 and 0.20) you can use the JobFlowInstancesConfig HadoopVersion parameter to modify the version of Hadoop from the defaults shown above.
            For details about the AMI versions currently supported by Amazon Elastic MapReduce, go to AMI Versions Supported in Elastic MapReduce in the Amazon Elastic MapReduce Developer's Guide.
            
    :type AmiVersion: string
    :param ReleaseLabel: 
            Note
            Amazon EMR releases 4.x or later.
            The release label for the Amazon EMR release. For Amazon EMR 3.x and 2.x AMIs, use amiVersion instead instead of ReleaseLabel.
            
    :type ReleaseLabel: string
    :param Instances: [REQUIRED]
            A specification of the number and type of Amazon EC2 instances on which to run the job flow.
            MasterInstanceType (string) --The EC2 instance type of the master node.
            SlaveInstanceType (string) --The EC2 instance type of the slave nodes.
            InstanceCount (integer) --The number of Amazon EC2 instances used to execute the job flow.
            InstanceGroups (list) --Configuration for the job flow's instance groups.
            (dict) --Configuration defining a new instance group.
            Name (string) --Friendly name given to the instance group.
            Market (string) --Market type of the Amazon EC2 instances used to create a cluster node.
            InstanceRole (string) -- [REQUIRED]The role of the instance group in the cluster.
            BidPrice (string) --Bid price for each Amazon EC2 instance in the instance group when launching nodes as Spot Instances, expressed in USD.
            InstanceType (string) -- [REQUIRED]The Amazon EC2 instance type for all instances in the instance group.
            InstanceCount (integer) -- [REQUIRED]Target number of instances for the instance group.
            Configurations (list) --
            Note
            Amazon EMR releases 4.x or later.
            The list of configurations supplied for an EMR cluster instance group. You can specify a separate configuration for each instance group (master, core, and task).
            (dict) --
            Note
            Amazon EMR releases 4.x or later.
            Specifies a hardware and software configuration of the EMR cluster. This includes configurations for applications and software bundled with Amazon EMR. The Configuration object is a JSON object which is defined by a classification and a set of properties. Configurations can be nested, so a configuration may have its own Configuration objects listed.
            Classification (string) --The classification of a configuration. For more information see, Amazon EMR Configurations .
            Configurations (list) --A list of configurations you apply to this configuration object.
            Properties (dict) --A set of properties supplied to the Configuration object.
            (string) --
            (string) --
            
            
            EbsConfiguration (dict) --EBS configurations that will be attached to each Amazon EC2 instance in the instance group.
            EbsBlockDeviceConfigs (list) --
            (dict) --Configuration of requested EBS block device associated with the instance group with count of volumes that will be associated to every instance.
            VolumeSpecification (dict) -- [REQUIRED]EBS volume specifications such as volume type, IOPS, and size(GiB) that will be requested for the EBS volume attached to an EC2 instance in the cluster.
            VolumeType (string) -- [REQUIRED]The volume type. Volume types supported are gp2, io1, standard.
            Iops (integer) --The number of I/O operations per second (IOPS) that the volume supports.
            SizeInGB (integer) -- [REQUIRED]The volume size, in gibibytes (GiB). This can be a number from 1 - 1024. If the volume type is EBS-optimized, the minimum value is 10.
            VolumesPerInstance (integer) --Number of EBS volumes with specific volume configuration, that will be associated with every instance in the instance group
            
            EbsOptimized (boolean) --
            
            Ec2KeyName (string) --The name of the Amazon EC2 key pair that can be used to ssh to the master node as the user called 'hadoop.'
            Placement (dict) --The Availability Zone the job flow will run in.
            AvailabilityZone (string) -- [REQUIRED]The Amazon EC2 Availability Zone for the job flow.
            KeepJobFlowAliveWhenNoSteps (boolean) --Specifies whether the job flow should be kept alive after completing all steps.
            TerminationProtected (boolean) --Specifies whether to lock the job flow to prevent the Amazon EC2 instances from being terminated by API call, user intervention, or in the event of a job flow error.
            HadoopVersion (string) --The Hadoop version for the job flow. Valid inputs are '0.18' (deprecated), '0.20' (deprecated), '0.20.205' (deprecated), '1.0.3', '2.2.0', or '2.4.0'. If you do not set this value, the default of 0.18 is used, unless the AmiVersion parameter is set in the RunJobFlow call, in which case the default version of Hadoop for that AMI version is used.
            Ec2SubnetId (string) --To launch the job flow in Amazon Virtual Private Cloud (Amazon VPC), set this parameter to the identifier of the Amazon VPC subnet where you want the job flow to launch. If you do not specify this value, the job flow is launched in the normal Amazon Web Services cloud, outside of an Amazon VPC.
            Amazon VPC currently does not support cluster compute quadruple extra large (cc1.4xlarge) instances. Thus you cannot specify the cc1.4xlarge instance type for nodes of a job flow launched in a Amazon VPC.
            EmrManagedMasterSecurityGroup (string) --The identifier of the Amazon EC2 security group for the master node.
            EmrManagedSlaveSecurityGroup (string) --The identifier of the Amazon EC2 security group for the slave nodes.
            ServiceAccessSecurityGroup (string) --The identifier of the Amazon EC2 security group for the Amazon EMR service to access clusters in VPC private subnets.
            AdditionalMasterSecurityGroups (list) --A list of additional Amazon EC2 security group IDs for the master node.
            (string) --
            AdditionalSlaveSecurityGroups (list) --A list of additional Amazon EC2 security group IDs for the slave nodes.
            (string) --
            
    :type Instances: dict
    :param Steps: A list of steps to be executed by the job flow.
            (dict) --Specification of a job flow step.
            Name (string) -- [REQUIRED]The name of the job flow step.
            ActionOnFailure (string) --The action to take if the job flow step fails.
            HadoopJarStep (dict) -- [REQUIRED]The JAR file used for the job flow step.
            Properties (list) --A list of Java properties that are set when the step runs. You can use these properties to pass key value pairs to your main function.
            (dict) --A key value pair.
            Key (string) --The unique identifier of a key value pair.
            Value (string) --The value part of the identified key.
            
            Jar (string) -- [REQUIRED]A path to a JAR file run during the step.
            MainClass (string) --The name of the main class in the specified Java file. If not specified, the JAR file should specify a Main-Class in its manifest file.
            Args (list) --A list of command line arguments passed to the JAR file's main function when executed.
            (string) --
            
            
    :type Steps: list
    :param BootstrapActions: A list of bootstrap actions that will be run before Hadoop is started on the cluster nodes.
            (dict) --
            Name (string) -- [REQUIRED]
            ScriptBootstrapAction (dict) -- [REQUIRED]
            Path (string) -- [REQUIRED]
            Args (list) --
            (string) --
            
            
    :type BootstrapActions: list
    :param SupportedProducts: 
            Note
            For Amazon EMR releases 3.x and 2.x. For Amazon EMR releases 4.x and greater, use Applications.
            A list of strings that indicates third-party software to use with the job flow. For more information, go to Use Third Party Applications with Amazon EMR . Currently supported values are:
            'mapr-m3' - launch the job flow using MapR M3 Edition.
            'mapr-m5' - launch the job flow using MapR M5 Edition.
            (string) --
            
    :type SupportedProducts: list
    :param NewSupportedProducts: 
            Note
            For Amazon EMR releases 3.x and 2.x. For Amazon EMR releases 4.x and greater, use Applications.
            A list of strings that indicates third-party software to use with the job flow that accepts a user argument list. EMR accepts and forwards the argument list to the corresponding installation script as bootstrap action arguments. For more information, see Launch a Job Flow on the MapR Distribution for Hadoop . Currently supported values are:
            'mapr-m3' - launch the cluster using MapR M3 Edition.
            'mapr-m5' - launch the cluster using MapR M5 Edition.
            'mapr' with the user arguments specifying '--edition,m3' or '--edition,m5' - launch the job flow using MapR M3 or M5 Edition respectively.
            'mapr-m7' - launch the cluster using MapR M7 Edition.
            'hunk' - launch the cluster with the Hunk Big Data Analtics Platform.
            'hue'- launch the cluster with Hue installed.
            'spark' - launch the cluster with Apache Spark installed.
            'ganglia' - launch the cluster with the Ganglia Monitoring System installed.
            (dict) --The list of supported product configurations which allow user-supplied arguments. EMR accepts these arguments and forwards them to the corresponding installation script as bootstrap action arguments.
            Name (string) --The name of the product configuration.
            Args (list) --The list of user-supplied arguments.
            (string) --
            
            
    :type NewSupportedProducts: list
    :param Applications: 
            Note
            Amazon EMR releases 4.x or later.
            A list of applications for the cluster. Valid values are: 'Hadoop', 'Hive', 'Mahout', 'Pig', and 'Spark.' They are case insensitive.
            (dict) --An application is any Amazon or third-party software that you can add to the cluster. This structure contains a list of strings that indicates the software to use with the cluster and accepts a user argument list. Amazon EMR accepts and forwards the argument list to the corresponding installation script as bootstrap action argument. For more information, see Launch a Job Flow on the MapR Distribution for Hadoop . Currently supported values are:
            'mapr-m3' - launch the job flow using MapR M3 Edition.
            'mapr-m5' - launch the job flow using MapR M5 Edition.
            'mapr' with the user arguments specifying '--edition,m3' or '--edition,m5' - launch the job flow using MapR M3 or M5 Edition, respectively.
            Note
            In Amazon EMR releases 4.0 and greater, the only accepted parameter is the application name. To pass arguments to applications, you supply a configuration for each application.
            Name (string) --The name of the application.
            Version (string) --The version of the application.
            Args (list) --Arguments for Amazon EMR to pass to the application.
            (string) --
            AdditionalInfo (dict) --This option is for advanced users only. This is meta information about third-party applications that third-party vendors use for testing purposes.
            (string) --
            (string) --
            
            
    :type Applications: list
    :param Configurations: 
            Note
            Amazon EMR releases 4.x or later.
            The list of configurations supplied for the EMR cluster you are creating.
            (dict) --
            Note
            Amazon EMR releases 4.x or later.
            Specifies a hardware and software configuration of the EMR cluster. This includes configurations for applications and software bundled with Amazon EMR. The Configuration object is a JSON object which is defined by a classification and a set of properties. Configurations can be nested, so a configuration may have its own Configuration objects listed.
            Classification (string) --The classification of a configuration. For more information see, Amazon EMR Configurations .
            Configurations (list) --A list of configurations you apply to this configuration object.
            Properties (dict) --A set of properties supplied to the Configuration object.
            (string) --
            (string) --
            
            
    :type Configurations: list
    :param VisibleToAllUsers: Whether the job flow is visible to all IAM users of the AWS account associated with the job flow. If this value is set to true , all IAM users of that AWS account can view and (if they have the proper policy permissions set) manage the job flow. If it is set to false , only the IAM user that created the job flow can view and manage it.
    :type VisibleToAllUsers: boolean
    :param JobFlowRole: Also called instance profile and EC2 role. An IAM role for an EMR cluster. The EC2 instances of the cluster assume this role. The default role is EMR_EC2_DefaultRole . In order to use the default role, you must have already created it using the CLI or console.
    :type JobFlowRole: string
    :param ServiceRole: The IAM role that will be assumed by the Amazon EMR service to access AWS resources on your behalf.
    :type ServiceRole: string
    :param Tags: A list of tags to associate with a cluster and propagate to Amazon EC2 instances.
            (dict) --A key/value pair containing user-defined metadata that you can associate with an Amazon EMR resource. Tags make it easier to associate clusters in various ways, such as grouping clusters to track your Amazon EMR resource allocation costs. For more information, see Tagging Amazon EMR Resources .
            Key (string) --A user-defined key, which is the minimum required information for a valid tag. For more information, see Tagging Amazon EMR Resources .
            Value (string) --A user-defined value, which is optional in a tag. For more information, see Tagging Amazon EMR Resources .
            
            
    :type Tags: list
    :param SecurityConfiguration: The name of a security configuration to apply to the cluster.
    :type SecurityConfiguration: string
    """
    pass

def set_termination_protection(JobFlowIds=None, TerminationProtected=None):
    """
    :param JobFlowIds: [REQUIRED]
            A list of strings that uniquely identify the job flows to protect. This identifier is returned by RunJobFlow and can also be obtained from DescribeJobFlows .
            (string) --
            
    :type JobFlowIds: list
    :param TerminationProtected: [REQUIRED]
            A Boolean that indicates whether to protect the job flow and prevent the Amazon EC2 instances in the cluster from shutting down due to API calls, user intervention, or job-flow error.
            
    :type TerminationProtected: boolean
    """
    pass

def set_visible_to_all_users(JobFlowIds=None, VisibleToAllUsers=None):
    """
    :param JobFlowIds: [REQUIRED]
            Identifiers of the job flows to receive the new visibility setting.
            (string) --
            
    :type JobFlowIds: list
    :param VisibleToAllUsers: [REQUIRED]
            Whether the specified job flows are visible to all IAM users of the AWS account associated with the job flow. If this value is set to True, all IAM users of that AWS account can view and, if they have the proper IAM policy permissions set, manage the job flows. If it is set to False, only the IAM user that created a job flow can view and manage it.
            
    :type VisibleToAllUsers: boolean
    """
    pass

def terminate_job_flows(JobFlowIds=None):
    """
    :param JobFlowIds: [REQUIRED]
            A list of job flows to be shutdown.
            (string) --
            ReturnsNone
            
    :type JobFlowIds: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_budget(AccountId=None, Budget=None, NotificationsWithSubscribers=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param Budget: [REQUIRED] AWS Budget model
            BudgetName (string) -- [REQUIRED] A string represents the budget name. No ':' character is allowed.
            BudgetLimit (dict) -- [REQUIRED] A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            CostFilters (dict) -- A map represents the cost filters applied to the budget.
            (string) -- A generic String.
            (list) --
            (string) -- A generic String.
            
            CostTypes (dict) -- [REQUIRED] This includes the options for getting the cost of a budget.
            IncludeTax (boolean) -- [REQUIRED] A generic boolean value.
            IncludeSubscription (boolean) -- [REQUIRED] A generic boolean value.
            UseBlended (boolean) -- [REQUIRED] A generic boolean value.
            TimeUnit (string) -- [REQUIRED] The time unit of the budget. e.g. weekly, monthly, etc.
            TimePeriod (dict) -- [REQUIRED] A time period indicated the start date and end date of a budget.
            Start (datetime) -- [REQUIRED] A generic timestamp. In Java it is transformed to a Date object.
            End (datetime) -- [REQUIRED] A generic timestamp. In Java it is transformed to a Date object.
            CalculatedSpend (dict) -- A structure holds the actual and forecasted spend for a budget.
            ActualSpend (dict) -- [REQUIRED] A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            ForecastedSpend (dict) -- A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            
            BudgetType (string) -- [REQUIRED] The type of a budget. Can be COST or USAGE.
            
    :type Budget: dict
    :param NotificationsWithSubscribers: A list of Notifications, each with a list of subscribers.
            (dict) -- A structure to relate notification and a list of subscribers who belong to the notification.
            Notification (dict) -- [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            Subscribers (list) -- [REQUIRED] A list of subscribers.
            (dict) -- Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
            
    :type NotificationsWithSubscribers: list
    """
    pass

def create_notification(AccountId=None, BudgetName=None, Notification=None, Subscribers=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    :param Subscribers: [REQUIRED] A list of subscribers.
            (dict) -- Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
    :type Subscribers: list
    """
    pass

def create_subscriber(AccountId=None, BudgetName=None, Notification=None, Subscriber=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    :param Subscriber: [REQUIRED] Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
    :type Subscriber: dict
    """
    pass

def delete_budget(AccountId=None, BudgetName=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    """
    pass

def delete_notification(AccountId=None, BudgetName=None, Notification=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    """
    pass

def delete_subscriber(AccountId=None, BudgetName=None, Notification=None, Subscriber=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    :param Subscriber: [REQUIRED] Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
    :type Subscriber: dict
    """
    pass

def describe_budget(AccountId=None, BudgetName=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    """
    pass

def describe_budgets(AccountId=None, MaxResults=None, NextToken=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param MaxResults: An integer to represent how many entries should a pagianted response contains. Maxium is set to 100.
    :type MaxResults: integer
    :param NextToken: A generic String.
    :type NextToken: string
    """
    pass

def describe_notifications_for_budget(AccountId=None, BudgetName=None, MaxResults=None, NextToken=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param MaxResults: An integer to represent how many entries should a pagianted response contains. Maxium is set to 100.
    :type MaxResults: integer
    :param NextToken: A generic String.
    :type NextToken: string
    """
    pass

def describe_subscribers_for_notification(AccountId=None, BudgetName=None, Notification=None, MaxResults=None, NextToken=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    :param MaxResults: An integer to represent how many entries should a pagianted response contains. Maxium is set to 100.
    :type MaxResults: integer
    :param NextToken: A generic String.
    :type NextToken: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def update_budget(AccountId=None, NewBudget=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param NewBudget: [REQUIRED] AWS Budget model
            BudgetName (string) -- [REQUIRED] A string represents the budget name. No ':' character is allowed.
            BudgetLimit (dict) -- [REQUIRED] A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            CostFilters (dict) -- A map represents the cost filters applied to the budget.
            (string) -- A generic String.
            (list) --
            (string) -- A generic String.
            
            CostTypes (dict) -- [REQUIRED] This includes the options for getting the cost of a budget.
            IncludeTax (boolean) -- [REQUIRED] A generic boolean value.
            IncludeSubscription (boolean) -- [REQUIRED] A generic boolean value.
            UseBlended (boolean) -- [REQUIRED] A generic boolean value.
            TimeUnit (string) -- [REQUIRED] The time unit of the budget. e.g. weekly, monthly, etc.
            TimePeriod (dict) -- [REQUIRED] A time period indicated the start date and end date of a budget.
            Start (datetime) -- [REQUIRED] A generic timestamp. In Java it is transformed to a Date object.
            End (datetime) -- [REQUIRED] A generic timestamp. In Java it is transformed to a Date object.
            CalculatedSpend (dict) -- A structure holds the actual and forecasted spend for a budget.
            ActualSpend (dict) -- [REQUIRED] A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            ForecastedSpend (dict) -- A structure represent either a cost spend or usage spend. Contains an amount and a unit.
            Amount (string) -- [REQUIRED] A string to represent NumericValue.
            Unit (string) -- [REQUIRED] A generic String.
            
            BudgetType (string) -- [REQUIRED] The type of a budget. Can be COST or USAGE.
            
    :type NewBudget: dict
    """
    pass

def update_notification(AccountId=None, BudgetName=None, OldNotification=None, NewNotification=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param OldNotification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type OldNotification: dict
    :param NewNotification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type NewNotification: dict
    """
    pass

def update_subscriber(AccountId=None, BudgetName=None, Notification=None, OldSubscriber=None, NewSubscriber=None):
    """
    :param AccountId: [REQUIRED] Account Id of the customer. It should be a 12 digit number.
    :type AccountId: string
    :param BudgetName: [REQUIRED] A string represents the budget name. No ':' character is allowed.
    :type BudgetName: string
    :param Notification: [REQUIRED] Notification model. Each budget may contain multiple notifications with different settings.
            NotificationType (string) -- [REQUIRED] The type of a notification. It should be ACTUAL or FORECASTED.
            ComparisonOperator (string) -- [REQUIRED] The comparison operator of a notification. Currently we support less than, equal to and greater than.
            Threshold (float) -- [REQUIRED] The threshold of the a notification. It should be a number between 0 and 100.
            
    :type Notification: dict
    :param OldSubscriber: [REQUIRED] Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
    :type OldSubscriber: dict
    :param NewSubscriber: [REQUIRED] Subscriber model. Each notification may contain multiple subscribers with different addresses.
            SubscriptionType (string) -- [REQUIRED] The subscription type of the subscriber. It can be SMS or EMAIL.
            Address (string) -- [REQUIRED] A generic String.
            
    :type NewSubscriber: dict
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_delivery_stream(DeliveryStreamName=None, S3DestinationConfiguration=None, RedshiftDestinationConfiguration=None, ElasticsearchDestinationConfiguration=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            
    :type DeliveryStreamName: string
    :param S3DestinationConfiguration: The destination in Amazon S3. This value must be specified if ElasticsearchDestinationConfiguration or RedshiftDestinationConfiguration is specified (see restrictions listed above).
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type S3DestinationConfiguration: dict
    :param RedshiftDestinationConfiguration: The destination in Amazon Redshift. This value cannot be specified if Amazon S3 or Amazon Elasticsearch is the desired destination (see restrictions listed above).
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            ClusterJDBCURL (string) -- [REQUIRED]The database connection string.
            CopyCommand (dict) -- [REQUIRED]The COPY command.
            DataTableName (string) -- [REQUIRED]The name of the target table. The table must already exist in the database.
            DataTableColumns (string) --A comma-separated list of column names.
            CopyOptions (string) --Optional parameters to use with the Amazon Redshift COPY command. For more information, see the 'Optional Parameters' section of Amazon Redshift COPY command . Some possible examples that would apply to Firehose are as follows.
            delimiter '\t' lzop; - fields are delimited with 't' (TAB character) and compressed using lzop.delimiter '| - fields are delimited with '|' (this is the default delimiter).
            delimiter '|' escape - the delimiter should be escaped.
            fixedwidth 'venueid:3,venuename:25,venuecity:12,venuestate:2,venueseats:6' - fields are fixed width in the source, with each width specified after every column in the table.
            JSON 's3://mybucket/jsonpaths.txt' - data is in JSON format, and the path specified is the format of the data.
            For more examples, see Amazon Redshift COPY command examples .
            Username (string) -- [REQUIRED]The name of the user.
            Password (string) -- [REQUIRED]The user password.
            RetryOptions (dict) --Configures retry behavior in the event that Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
            DurationInSeconds (integer) --The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of DurationInSeconds is 0 (zero) or if the first delivery attempt takes longer than the current value.
            S3Configuration (dict) -- [REQUIRED]The S3 configuration for the intermediate location from which Amazon Redshift obtains data. Restrictions are described in the topic for CreateDeliveryStream .
            The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationConfiguration.S3Configuration because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type RedshiftDestinationConfiguration: dict
    :param ElasticsearchDestinationConfiguration: The destination in Amazon ES. This value cannot be specified if Amazon S3 or Amazon Redshift is the desired destination (see restrictions listed above).
            RoleARN (string) -- [REQUIRED]The ARN of the IAM role to be assumed by Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see Amazon S3 Bucket Access .
            DomainARN (string) -- [REQUIRED]The ARN of the Amazon ES domain. The IAM role must have permission for DescribeElasticsearchDomain , DescribeElasticsearchDomains , and DescribeElasticsearchDomainConfig after assuming RoleARN .
            IndexName (string) -- [REQUIRED]The Elasticsearch index name.
            TypeName (string) -- [REQUIRED]The Elasticsearch type name.
            IndexRotationPeriod (string) --The Elasticsearch index rotation period. Index rotation appends a timestamp to the IndexName to facilitate expiration of old data. For more information, see Index Rotation for Amazon Elasticsearch Service Destination . Default value is OneDay .
            BufferingHints (dict) --Buffering options. If no value is specified, ElasticsearchBufferingHints object default values are used.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, set SizeInMBs to be 10 MB or higher.
            RetryOptions (dict) --Configures retry behavior in the event that Firehose is unable to deliver documents to Amazon ES. Default value is 300 (5 minutes).
            DurationInSeconds (integer) --After an initial failure to deliver to Amazon ES, the total amount of time during which Firehose re-attempts delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
            S3BackupMode (string) --Defines how documents should be delivered to Amazon S3. When set to FailedDocumentsOnly, Firehose writes any documents that could not be indexed to the configured Amazon S3 destination, with elasticsearch-failed/ appended to the key prefix. When set to AllDocuments, Firehose delivers all incoming records to Amazon S3, and also writes failed documents with elasticsearch-failed/ appended to the prefix. For more information, see Amazon S3 Backup for Amazon Elasticsearch Service Destination . Default value is FailedDocumentsOnly.
            S3Configuration (dict) -- [REQUIRED]Describes the configuration of a destination in Amazon S3.
            RoleARN (string) -- [REQUIRED]The ARN of the AWS credentials.
            BucketARN (string) -- [REQUIRED]The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is UNCOMPRESSED .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type ElasticsearchDestinationConfiguration: dict
    """
    pass

def delete_delivery_stream(DeliveryStreamName=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Contains the output of DeleteDeliveryStream .
            
            
    :type DeliveryStreamName: string
    """
    pass

def describe_delivery_stream(DeliveryStreamName=None, Limit=None, ExclusiveStartDestinationId=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            
    :type DeliveryStreamName: string
    :param Limit: The limit on the number of destinations to return. Currently, you can have one destination per delivery stream.
    :type Limit: integer
    :param ExclusiveStartDestinationId: Specifies the destination ID to start returning the destination information. Currently Firehose supports one destination per delivery stream.
    :type ExclusiveStartDestinationId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_delivery_streams(Limit=None, ExclusiveStartDeliveryStreamName=None):
    """
    :param Limit: The maximum number of delivery streams to list.
    :type Limit: integer
    :param ExclusiveStartDeliveryStreamName: The name of the delivery stream to start the list with.
    :type ExclusiveStartDeliveryStreamName: string
    """
    pass

def put_record(DeliveryStreamName=None, Record=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            
    :type DeliveryStreamName: string
    :param Record: [REQUIRED]
            The record.
            Data (bytes) -- [REQUIRED]The data blob, which is base64-encoded when the blob is serialized. The maximum size of the data blob, before base64-encoding, is 1,000 KB.
            
    :type Record: dict
    """
    pass

def put_record_batch(DeliveryStreamName=None, Records=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            
    :type DeliveryStreamName: string
    :param Records: [REQUIRED]
            One or more records.
            (dict) --The unit of data in a delivery stream.
            Data (bytes) -- [REQUIRED]The data blob, which is base64-encoded when the blob is serialized. The maximum size of the data blob, before base64-encoding, is 1,000 KB.
            
            
    :type Records: list
    """
    pass

def update_destination(DeliveryStreamName=None, CurrentDeliveryStreamVersionId=None, DestinationId=None, S3DestinationUpdate=None, RedshiftDestinationUpdate=None, ElasticsearchDestinationUpdate=None):
    """
    :param DeliveryStreamName: [REQUIRED]
            The name of the delivery stream.
            
    :type DeliveryStreamName: string
    :param CurrentDeliveryStreamVersionId: [REQUIRED]
            Obtain this value from the VersionId result of the DeliveryStreamDescription operation. This value is required, and helps the service to perform conditional operations. For example, if there is a interleaving update and this value is null, then the update destination fails. After the update is successful, the VersionId value is updated. The service then performs a merge of the old configuration with the new configuration.
            
    :type CurrentDeliveryStreamVersionId: string
    :param DestinationId: [REQUIRED]
            The ID of the destination.
            
    :type DestinationId: string
    :param S3DestinationUpdate: Describes an update for a destination in Amazon S3.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is NOCOMPRESSION .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type S3DestinationUpdate: dict
    :param RedshiftDestinationUpdate: Describes an update for a destination in Amazon Redshift.
            RoleARN (string) --The ARN of the AWS credentials.
            ClusterJDBCURL (string) --The database connection string.
            CopyCommand (dict) --The COPY command.
            DataTableName (string) -- [REQUIRED]The name of the target table. The table must already exist in the database.
            DataTableColumns (string) --A comma-separated list of column names.
            CopyOptions (string) --Optional parameters to use with the Amazon Redshift COPY command. For more information, see the 'Optional Parameters' section of Amazon Redshift COPY command . Some possible examples that would apply to Firehose are as follows.
            delimiter '\t' lzop; - fields are delimited with 't' (TAB character) and compressed using lzop.delimiter '| - fields are delimited with '|' (this is the default delimiter).
            delimiter '|' escape - the delimiter should be escaped.
            fixedwidth 'venueid:3,venuename:25,venuecity:12,venuestate:2,venueseats:6' - fields are fixed width in the source, with each width specified after every column in the table.
            JSON 's3://mybucket/jsonpaths.txt' - data is in JSON format, and the path specified is the format of the data.
            For more examples, see Amazon Redshift COPY command examples .
            Username (string) --The name of the user.
            Password (string) --The user password.
            RetryOptions (dict) --Configures retry behavior in the event that Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
            DurationInSeconds (integer) --The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of DurationInSeconds is 0 (zero) or if the first delivery attempt takes longer than the current value.
            S3Update (dict) --The Amazon S3 destination.
            The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationUpdate.S3Update because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is NOCOMPRESSION .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type RedshiftDestinationUpdate: dict
    :param ElasticsearchDestinationUpdate: Describes an update for a destination in Amazon ES.
            RoleARN (string) --The ARN of the IAM role to be assumed by Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see Amazon S3 Bucket Access .
            DomainARN (string) --The ARN of the Amazon ES domain. The IAM role must have permission for DescribeElasticsearchDomain, DescribeElasticsearchDomains , and DescribeElasticsearchDomainConfig after assuming RoleARN .
            IndexName (string) --The Elasticsearch index name.
            TypeName (string) --The Elasticsearch type name.
            IndexRotationPeriod (string) --The Elasticsearch index rotation period. Index rotation appends a timestamp to the IndexName to facilitate the expiration of old data. For more information, see Index Rotation for Amazon Elasticsearch Service Destination . Default value is OneDay .
            BufferingHints (dict) --Buffering options. If no value is specified, ElasticsearchBufferingHints object default values are used.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, set SizeInMBs to be 10 MB or higher.
            RetryOptions (dict) --Configures retry behavior in the event that Firehose is unable to deliver documents to Amazon ES. Default value is 300 (5 minutes).
            DurationInSeconds (integer) --After an initial failure to deliver to Amazon ES, the total amount of time during which Firehose re-attempts delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
            S3Update (dict) --Describes an update for a destination in Amazon S3.
            RoleARN (string) --The ARN of the AWS credentials.
            BucketARN (string) --The ARN of the S3 bucket.
            Prefix (string) --The 'YYYY/MM/DD/HH' time format prefix is automatically used for delivered S3 files. You can specify an extra prefix to be added in front of the time format prefix. Note that if the prefix ends with a slash, it appears as a folder in the S3 bucket. For more information, see Amazon S3 Object Name Format in the Amazon Kinesis Firehose Developer Guide .
            BufferingHints (dict) --The buffering option. If no value is specified, BufferingHints object default values are used.
            SizeInMBs (integer) --Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
            We recommend setting SizeInMBs to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec set SizeInMBs to be 10 MB or higher.
            IntervalInSeconds (integer) --Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300.
            CompressionFormat (string) --The compression format. If no value is specified, the default is NOCOMPRESSION .
            The compression formats SNAPPY or ZIP cannot be specified for Amazon Redshift destinations because they are not supported by the Amazon Redshift COPY operation that reads from the S3 bucket.
            EncryptionConfiguration (dict) --The encryption configuration. If no value is specified, the default is no encryption.
            NoEncryptionConfig (string) --Specifically override existing encryption information to ensure no encryption is used.
            KMSEncryptionConfig (dict) --The encryption key.
            AWSKMSKeyARN (string) -- [REQUIRED]The ARN of the encryption key. Must belong to the same region as the destination Amazon S3 bucket.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            CloudWatchLoggingOptions (dict) --Describes CloudWatch logging options for your delivery stream.
            Enabled (boolean) --Enables or disables CloudWatch logging.
            LogGroupName (string) --The CloudWatch group name for logging. This value is required if Enabled is true.
            LogStreamName (string) --The CloudWatch log stream name for logging. This value is required if Enabled is true.
            
            
    :type ElasticsearchDestinationUpdate: dict
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def delete_alarms(AlarmNames=None):
    """
    :param AlarmNames: [REQUIRED]
            A list of alarms to be deleted.
            (string) --
            ReturnsNone
            
    :type AlarmNames: list
    """
    pass

def describe_alarm_history(AlarmName=None, HistoryItemType=None, StartDate=None, EndDate=None, MaxRecords=None, NextToken=None):
    """
    :param AlarmName: The name of the alarm.
    :type AlarmName: string
    :param HistoryItemType: The type of alarm histories to retrieve.
    :type HistoryItemType: string
    :param StartDate: The starting date to retrieve alarm history.
    :type StartDate: datetime
    :param EndDate: The ending date to retrieve alarm history.
    :type EndDate: datetime
    :param MaxRecords: The maximum number of alarm history records to retrieve.
    :type MaxRecords: integer
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    """
    pass

def describe_alarms(AlarmNames=None, AlarmNamePrefix=None, StateValue=None, ActionPrefix=None, MaxRecords=None, NextToken=None):
    """
    :param AlarmNames: A list of alarm names to retrieve information for.
            (string) --
            
    :type AlarmNames: list
    :param AlarmNamePrefix: The alarm name prefix. AlarmNames cannot be specified if this parameter is specified.
    :type AlarmNamePrefix: string
    :param StateValue: The state value to be used in matching alarms.
    :type StateValue: string
    :param ActionPrefix: The action name prefix.
    :type ActionPrefix: string
    :param MaxRecords: The maximum number of alarm descriptions to retrieve.
    :type MaxRecords: integer
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    """
    pass

def describe_alarms_for_metric(MetricName=None, Namespace=None, Statistic=None, Dimensions=None, Period=None, Unit=None):
    """
    :param MetricName: [REQUIRED]
            The name of the metric.
            
    :type MetricName: string
    :param Namespace: [REQUIRED]
            The namespace of the metric.
            
    :type Namespace: string
    :param Statistic: The statistic for the metric.
    :type Statistic: string
    :param Dimensions: The list of dimensions associated with the metric. If the metric has any associated dimensions, you must specify them in order for the DescribeAlarmsForMetric to succeed.
            (dict) --The Dimension data type further expands on the identity of a metric using a Name, Value pair.
            For examples that use one or more dimensions, see PutMetricData .
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement
            
            
    :type Dimensions: list
    :param Period: The period in seconds over which the statistic is applied.
    :type Period: integer
    :param Unit: The unit for the metric.
    :type Unit: string
    """
    pass

def disable_alarm_actions(AlarmNames=None):
    """
    :param AlarmNames: [REQUIRED]
            The names of the alarms to disable actions for.
            (string) --
            ReturnsNone
            
    :type AlarmNames: list
    """
    pass

def enable_alarm_actions(AlarmNames=None):
    """
    :param AlarmNames: [REQUIRED]
            The names of the alarms to enable actions for.
            (string) --
            ReturnsNone
            
    :type AlarmNames: list
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_metric_statistics(Namespace=None, MetricName=None, Dimensions=None, StartTime=None, EndTime=None, Period=None, Statistics=None, Unit=None):
    """
    :param Namespace: [REQUIRED]
            The namespace of the metric, with or without spaces.
            
    :type Namespace: string
    :param MetricName: [REQUIRED]
            The name of the metric, with or without spaces.
            
    :type MetricName: string
    :param Dimensions: A list of dimensions describing qualities of the metric.
            (dict) --The Dimension data type further expands on the identity of a metric using a Name, Value pair.
            For examples that use one or more dimensions, see PutMetricData .
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement
            
            
    :type Dimensions: list
    :param StartTime: [REQUIRED]
            The time stamp to use for determining the first datapoint to return. The value specified is inclusive; results include datapoints with the time stamp specified. The time stamp must be in ISO 8601 UTC format (e.g., 2014-09-03T23:00:00Z).
            Note
            The specified start time is rounded down to the nearest value. Datapoints are returned for start times up to two weeks in the past. Specified start times that are more than two weeks in the past will not return datapoints for metrics that are older than two weeks.
            Data that is timestamped 24 hours or more in the past may take in excess of 48 hours to become available from submission time using GetMetricStatistics .
            
    :type StartTime: datetime
    :param EndTime: [REQUIRED]
            The time stamp to use for determining the last datapoint to return. The value specified is exclusive; results will include datapoints up to the time stamp specified. The time stamp must be in ISO 8601 UTC format (e.g., 2014-09-03T23:00:00Z).
            
    :type EndTime: datetime
    :param Period: [REQUIRED]
            The granularity, in seconds, of the returned datapoints. A Period can be as short as one minute (60 seconds) or as long as one day (86,400 seconds), and must be a multiple of 60. The default value is 60.
            
    :type Period: integer
    :param Statistics: [REQUIRED]
            The metric statistics to return. For information about specific statistics returned by GetMetricStatistics, see Statistics in the Amazon CloudWatch Developer Guide .
            (string) --
            
    :type Statistics: list
    :param Unit: The specific unit for a given metric. Metrics may be reported in multiple units. Not supplying a unit results in all units being returned. If the metric only ever reports one unit, specifying a unit will have no effect.
    :type Unit: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_metrics(Namespace=None, MetricName=None, Dimensions=None, NextToken=None):
    """
    :param Namespace: The namespace to filter against.
    :type Namespace: string
    :param MetricName: The name of the metric to filter against.
    :type MetricName: string
    :param Dimensions: A list of dimensions to filter against.
            (dict) --The DimensionFilter data type is used to filter ListMetrics results.
            Name (string) -- [REQUIRED]The dimension name to be matched.
            Value (string) --The value of the dimension to be matched.
            Note
            Specifying a Name without specifying a Value returns all values associated with that Name .
            
            
    :type Dimensions: list
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    """
    pass

def put_metric_alarm(AlarmName=None, AlarmDescription=None, ActionsEnabled=None, OKActions=None, AlarmActions=None, InsufficientDataActions=None, MetricName=None, Namespace=None, Statistic=None, Dimensions=None, Period=None, Unit=None, EvaluationPeriods=None, Threshold=None, ComparisonOperator=None):
    """
    :param AlarmName: [REQUIRED]
            The descriptive name for the alarm. This name must be unique within the user's AWS account
            
    :type AlarmName: string
    :param AlarmDescription: The description for the alarm.
    :type AlarmDescription: string
    :param ActionsEnabled: Indicates whether or not actions should be executed during any changes to the alarm's state.
    :type ActionsEnabled: boolean
    :param OKActions: The list of actions to execute when this alarm transitions into an OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region (e.g., us-east-1) :ec2:stop | arn:aws:automate:region (e.g., us-east-1) :ec2:terminate | arn:aws:automate:region (e.g., us-east-1) :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            Note: You must create at least one stop, terminate, or reboot alarm using the Amazon EC2 or CloudWatch console to create the EC2ActionsAccess IAM role for the first time. After this IAM role is created, you can create stop, terminate, or reboot alarms using the CLI.
            (string) --
            
    :type OKActions: list
    :param AlarmActions: The list of actions to execute when this alarm transitions into an ALARM state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region (e.g., us-east-1) :ec2:stop | arn:aws:automate:region (e.g., us-east-1) :ec2:terminate | arn:aws:automate:region (e.g., us-east-1) :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            Note: You must create at least one stop, terminate, or reboot alarm using the Amazon EC2 or CloudWatch console to create the EC2ActionsAccess IAM role for the first time. After this IAM role is created, you can create stop, terminate, or reboot alarms using the CLI.
            (string) --
            
    :type AlarmActions: list
    :param InsufficientDataActions: The list of actions to execute when this alarm transitions into an INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
            Valid Values: arn:aws:automate:region (e.g., us-east-1) :ec2:stop | arn:aws:automate:region (e.g., us-east-1) :ec2:terminate | arn:aws:automate:region (e.g., us-east-1) :ec2:recover
            Valid Values (for use with IAM roles): arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Stop/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Terminate/1.0 | arn:aws:swf:us-east-1:{customer-account }:action/actions/AWS_EC2.InstanceId.Reboot/1.0
            Note: You must create at least one stop, terminate, or reboot alarm using the Amazon EC2 or CloudWatch console to create the EC2ActionsAccess IAM role for the first time. After this IAM role is created, you can create stop, terminate, or reboot alarms using the CLI.
            (string) --
            
    :type InsufficientDataActions: list
    :param MetricName: [REQUIRED]
            The name for the alarm's associated metric.
            
    :type MetricName: string
    :param Namespace: [REQUIRED]
            The namespace for the alarm's associated metric.
            
    :type Namespace: string
    :param Statistic: [REQUIRED]
            The statistic to apply to the alarm's associated metric.
            
    :type Statistic: string
    :param Dimensions: The dimensions for the alarm's associated metric.
            (dict) --The Dimension data type further expands on the identity of a metric using a Name, Value pair.
            For examples that use one or more dimensions, see PutMetricData .
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement
            
            
    :type Dimensions: list
    :param Period: [REQUIRED]
            The period in seconds over which the specified statistic is applied.
            
    :type Period: integer
    :param Unit: The statistic's unit of measure. For example, the units for the Amazon EC2 NetworkIn metric are Bytes because NetworkIn tracks the number of bytes that an instance receives on all network interfaces. You can also specify a unit when you create a custom metric. Units help provide conceptual meaning to your data. Metric data points that specify a unit of measure, such as Percent, are aggregated separately.
            Note: If you specify a unit, you must use a unit that is appropriate for the metric. Otherwise, this can cause an Amazon CloudWatch alarm to get stuck in the INSUFFICIENT DATA state.
            
    :type Unit: string
    :param EvaluationPeriods: [REQUIRED]
            The number of periods over which data is compared to the specified threshold.
            
    :type EvaluationPeriods: integer
    :param Threshold: [REQUIRED]
            The value against which the specified statistic is compared.
            
    :type Threshold: float
    :param ComparisonOperator: [REQUIRED]
            The arithmetic operation to use when comparing the specified Statistic and Threshold . The specified Statistic value is used as the first operand.
            
    :type ComparisonOperator: string
    """
    pass

def put_metric_data(Namespace=None, MetricData=None):
    """
    :param Namespace: [REQUIRED]
            The namespace for the metric data.
            Note
            You cannot specify a namespace that begins with 'AWS/'. Namespaces that begin with 'AWS/' are reserved for other Amazon Web Services products that send metrics to Amazon CloudWatch.
            
    :type Namespace: string
    :param MetricData: [REQUIRED]
            A list of data describing the metric.
            (dict) --The MetricDatum data type encapsulates the information sent with PutMetricData to either create a new metric or add new values to be aggregated into an existing metric.
            MetricName (string) -- [REQUIRED]The name of the metric.
            Dimensions (list) --A list of dimensions associated with the metric. Note, when using the Dimensions value in a query, you need to append .member.N to it (e.g., Dimensions.member.N).
            (dict) --The Dimension data type further expands on the identity of a metric using a Name, Value pair.
            For examples that use one or more dimensions, see PutMetricData .
            Name (string) -- [REQUIRED]The name of the dimension.
            Value (string) -- [REQUIRED]The value representing the dimension measurement
            
            Timestamp (datetime) --The time stamp used for the metric in ISO 8601 Universal Coordinated Time (UTC) format. If not specified, the default value is set to the time the metric data was received.
            Value (float) --The value for the metric.
            Warning
            Although the Value parameter accepts numbers of type Double , Amazon CloudWatch rejects values that are either too small or too large. Values must be in the range of 8.515920e-109 to 1.174271e+108 (Base 10) or 2e-360 to 2e360 (Base 2). In addition, special values (e.g., NaN, +Infinity, -Infinity) are not supported.
            StatisticValues (dict) --A set of statistical values describing the metric.
            SampleCount (float) -- [REQUIRED]The number of samples used for the statistic set.
            Sum (float) -- [REQUIRED]The sum of values for the sample set.
            Minimum (float) -- [REQUIRED]The minimum value of the sample set.
            Maximum (float) -- [REQUIRED]The maximum value of the sample set.
            Unit (string) --The unit of the metric.
            
            
    :type MetricData: list
    """
    pass

def set_alarm_state(AlarmName=None, StateValue=None, StateReason=None, StateReasonData=None):
    """
    :param AlarmName: [REQUIRED]
            The descriptive name for the alarm. This name must be unique within the user's AWS account. The maximum length is 255 characters.
            
    :type AlarmName: string
    :param StateValue: [REQUIRED]
            The value of the state.
            
    :type StateValue: string
    :param StateReason: [REQUIRED]
            The reason that this alarm is set to this specific state (in human-readable text format)
            
    :type StateReason: string
    :param StateReasonData: The reason that this alarm is set to this specific state (in machine-readable JSON format)
    :type StateReasonData: string
    """
    pass

